@@ -2,10 +2,11 @@ from adbpy.socket import Socket
 from adbpy import Target, AdbError
 from adbpy.host_command import host_command
 from adbpy.devices import parse_device_list
+from adbpy.adb_process import AdbProcess
 
 class Adb(object):
 
-    def __init__(self, address=None):
+    def __init__(self, address=None, adb_path="adb"):
         """
         Initialize an Adb object
 
@@ -18,17 +19,18 @@ class Adb(object):
 
         self.address = address
         self.socket = Socket(address)
+        self.process = AdbProcess(adb_path, address)
 
-    def command(self, data):
+    def _command(self, data):
         self.socket.send(data)
         return self.socket.receive()
 
-    def command_bool(self, data):
+    def _command_bool(self, data):
         self.socket.send(data)
         return self.socket.receive_fixed_length(4) == "OKAY"
 
     @staticmethod
-    def get_transport(target):
+    def _get_transport(target):
         transport = ''
         if target in Target.__dict__.values():
             transport =  "-" + target
@@ -37,52 +39,87 @@ class Adb(object):
             transport = ":" + target
         return "host:transport" + transport
 
-    def setup_target(self, target):
-        self.socket.send(Adb.get_transport(target))
+    def _setup_target(self, target):
+        self.socket.send(Adb._get_transport(target))
         if self.socket.receive_fixed_length(4) != "OKAY":
             raise AdbError("Failed to change transport.  Verify that multiple devices "
                            "are not connected and that you chose the right target")
 
     def start(self):
-        pass
+        """
+        Start the ADB server on the port specified in :py:attr:`Adb.address` during initialization.
+        Throws an error if the server doesn't actually start on the expected port.
+
+        :raises: AdbError
+        """
+        self.process.start()
+        if not self.process.started():
+            raise AdbError("Failed to start Adb process")
 
     def devices(self):
+        """
+        Return a list of connected devices in the form (*serial*, *status*) where status can
+        be any of the following:
+
+        1. device
+        2. offline
+        3. unauthorized
+
+        :returns: A list of tuples representing connected devices
+        """
         devices = None
         with self.socket.Connect():
-            devices = self.command("host:devices")
+            devices = self._command("host:devices")
 
         return parse_device_list(devices)
 
     def version(self):
+        """
+        Get the version of the ADB server (for example 1.0.31).
+
+        :returns: The version of the ADB server (ex.
+        """
         with self.socket.Connect():
-            return self.command("host:version")
+            return self._command("host:version")
 
     def kill(self):
+        """
+        Kill the current ADB server.
+
+        :returns: True if the ADB server was killed.
+        """
         with self.socket.Connect():
-            try:
-                return self.command_bool("host:kill")
-            except RuntimeError:
-                pass
+            return self._command_bool("host:kill")
 
     def get_product(self, target=Target.ANY):
+        """
+        Get the product name corresponding to *target*.
+
+        :returns: The product name
+        """
         cmd = host_command(target, "get-product")
         with self.socket.Connect():
-            return self.command(cmd)
+            return self._command(cmd)
 
     def get_serialno(self, target=Target.ANY):
+        """
+        Get the serial number of *target*
+
+        :returns: The serial number
+        """
         cmd = host_command(target, "get-serialno")
         with self.socket.Connect():
-            return self.command(cmd)
+            return self._command(cmd)
 
     def get_devpath(self, target=Target.ANY):
         cmd = host_command(target, "get-devpath")
         with self.socket.Connect():
-            return self.command(cmd)
+            return self._command(cmd)
 
     def get_state(self, target=Target.ANY):
         cmd = host_command(target, "get-state")
         with self.socket.Connect():
-            return self.command(cmd)
+            return self._command(cmd)
 
     def forward(self, local, remote, target=Target.ANY, norebind=False):
         cmd_start = "forward:"
@@ -93,20 +130,20 @@ class Adb(object):
         cmd = host_command(target, base_command)
 
         with self.socket.Connect():
-            return self.command_bool(cmd)
+            return self._command_bool(cmd)
 
     def kill_forward(self, local, target=Target.ANY):
         cmd = host_command(target, "killforward:" + local)
         with self.socket.Connect():
-            return self.command_bool(cmd)
+            return self._command_bool(cmd)
 
     def kill_forward_all(self, target=Target.ANY):
         cmd = host_command(target, "killforward-all")
         with self.socket.Connect():
-            return self.command_bool(cmd)
+            return self._command_bool(cmd)
 
     def shell(self, shell_cmd, target=Target.ANY, timeout=None):
         with self.socket.Connect():
-            self.setup_target(target)
+            self._setup_target(target)
             self.socket.send("shell:" + shell_cmd)
             return self.socket.receive_until_end(timeout)
